bn

Module arith

Structs

  • 256-bit, stack allocated biginteger for use in prime field arithmetic.
  • 512-bit, stack allocated biginteger for use in extension field serialization and scalar interpretation.

Enums