Module bean

Module bean 

Structs

AttemptRecord
A single attempt record (claim→close cycle).
Bean
RunRecord
A single verification run record.

Enums

AttemptOutcome
Outcome of a claim→close cycle.
OnCloseAction
Declarative actions to run when a bean is closed. Processed after the bean is archived and post-close hook fires.
OnFailAction
Declarative action to run when a bean’s verify command fails.
RunResult
Outcome of a verification run.
Status

Functions

validate_priority
Validate that priority is in the valid range (0-4, P0-P4).