Module blocking

Module blocking 

Enums

BlockReason
Why a bean cannot be dispatched right now.
ScopeWarning
Soft scope warnings — displayed but don’t block dispatch.

Constants

MAX_PATHS
Maximum number of paths before a bean is considered oversized.
MAX_PRODUCES
Maximum number of produces artifacts before a bean is considered oversized.

Functions

check_blocked
Check whether entry is blocked, returning the reason if so.
check_scope_warning
Check for scope warnings (non-blocking).