Structs
- Create
Args - Create arguments structure for organizing all the parameters passed to create.
Functions
- assign_
child_ id - Assign a child ID for a parent bean. Scans .beans/ for {parent_id}.{N}-*.md, finds highest N, returns “{parent_id}.{N+1}”.
- cmd_
create - Create a new bean.
- cmd_
create_ next - Create a new bean that automatically depends on @latest (the most recently updated bean).
- parse_
on_ fail - Parse an
--on-failCLI string into anOnFailAction.