Module logs

Module logs 

Functions

cmd_logs
View agent output from log files.
find_all_logs
Find all log files for a bean, sorted oldest to newest.
find_latest_log
Find the most recent log file for a bean.
log_dir
Return the log directory path, creating it if needed.