Structs
- Attempt
Record - A single attempt record (claim→close cycle).
- Bean
- RunRecord
- A single verification run record.
Enums
- Attempt
Outcome - Outcome of a claim→close cycle.
- OnClose
Action - Declarative actions to run when a bean is closed. Processed after the bean is archived and post-close hook fires.
- OnFail
Action - Declarative action to run when a bean’s verify command fails.
- RunResult
- Outcome of a verification run.
- Status
Functions
- validate_
priority - Validate that priority is in the valid range (0-4, P0-P4).