Module create

Module create 

Structs

CreateArgs
Create arguments structure for organizing all the parameters passed to create.

Functions

assign_child_id
Assign a child ID for a parent bean. Scans .beans/ for {parent_id}.{N}-*.md, finds highest N, returns “{parent_id}.{N+1}”.
cmd_create
Create a new bean.
cmd_create_next
Create a new bean that automatically depends on @latest (the most recently updated bean).
parse_on_fail
Parse an --on-fail CLI string into an OnFailAction.